==> cms-db_v0.7.11.tar.gz: admin/locales/it/locale_variables.php <==
<?php
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    For a full list of authors, see info.php
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

$locale['variables'] = array();

$locale['variables']['title'] = 'Variabili';
$locale['variables']['desc'] = 'Puoi utilizzare tutte le variabili all\'interno del <a href="%s">template</a>, le variabili, ad eccezione di PAGECONTENT, possono anche essere utilizzate nelle <a href="%s">pagine</a>. Non è permesso l\'inserimento di variabili all\'interno di commenti nel libro degli ospiti o negli articoli del blog.';

$locale['variables']['desc_p-allowed'] = 'può essere inserita in un paragrafo';
$locale['variables']['desc_p-alone'] = 'può essere inserita in un paragrafo, a condizione che il paragrafo non contenga altro.';
$locale['variables']['desc_p-disallowed'] = 'non può essere inserita in un paragrafo';
$locale['variables']['desc_p-needed'] = 'deve essere inserita in un paragrafo ed esserne l\'unico contenuto';

$locale['variables']['desc_topmenu'] = 'Genera un menù delle pagine primarie';
$locale['variables']['desc_completesubmenu'] = 'Genera un menù di tutte le pagine secondarie rispetto all\'attuale pagina primaria';
$locale['variables']['desc_foldingsubmenu'] = 'Genera un menù di tutte le pagine secondarie rispetto all\'attuale pagina primaria, relativo alla pagina secondaria attiva ';
$locale['variables']['desc_completemenu'] = 'Genera un menù completo del sito';
$locale['variables']['desc_foldingmenu'] = 'Genera un menù completo del sito, relativo alla pagina attiva';
$locale['variables']['desc_pagesearch'] = 'Genera un campo di ricerca';
$locale['variables']['desc_pagetitle'] = 'Nome della pagina corrente';
$locale['variables']['desc_fulltitle'] = 'Nome della pagina corrente e struttura della pagina';
$locale['variables']['desc_breadcrumbs'] = 'Come %%FULLTITLE%%, ma con link alle pagine';
$locale['variables']['desc_pagecontent'] = 'Contenuto della pagina corrente';
$locale['variables']['desc_lastedit'] = 'Data e orario dell\'ultima modifica alla pagina corrente';
$locale['variables']['desc_pagecount'] = 'Numero di visite alla pagina';
$locale['variables']['desc_counter'] = 'Numero di visitatori';
$locale['variables']['desc_sitemap'] = 'Genera una mappa del sito (se inserita in un paragrafo, questo verrà automaticamente rimosso)';
$locale['variables']['desc_mailform'] = 'Genera un modulo di contatto che manda un messaggio via email all\'indirizzo specificato in luogo di ADDRESS (se inserita in un paragrafo, questo verrà automaticamente rimosso)';
$locale['variables']['desc_guestbook'] = 'Libro degli ospiti, la codifica deve essere UTF-8 (se inserita in un paragrafo, questo verrà automaticamente rimosso)';
$locale['variables']['desc_blog'] = 'Blog, la codifica deve essere UTF-8 (se inserita in un paragrafo, questo verrà automaticamente rimosso)';
$locale['variables']['desc_latestblogarticles'] = 'Lista degli ultimi articoli del blog, PAGE è l\'URL relativo della pagina contenente il blog';
$locale['variables']['desc_tagcloud'] = 'Tag cloud (nuvola dei tag) del blog, PAGE è l\'URL relativo della pagina contenente il blog';
$locale['variables']['desc_sectionlist'] = 'Lista dei link alle pagine secondarie della pagina corrente (se inserita in un paragrafo, questo verrà automaticamente rimosso)';
$locale['variables']['desc_loginform'] = 'Modulo per il login (se inserita in un paragrafo, questo verrà automaticamente rimosso)';
$locale['variables']['desc_include'] = 'Inserisce l\'include NAME (se inserita in un paragrafo, questo verrà automaticamente rimosso)';
$locale['variables']['desc_redirect'] = 'Redirect all\'URL, i contenuti della pagina non veranno mostrati';
$locale['variables']['desc_forcelanguage'] = 'Imposta la lingua utilizzata per generare i contenuti al valore specificato con LANGCODE';
$locale['variables']['desc_urlsettings'] = 'Ritorna le impostazioni per l\'URL';
$locale['variables']['desc_condition'] = 'Il contenuto inserito tra le due variabili sarà mostrato solo nel caso che il valore di COND sia "true", %%CONDITION-(COND)%% e %%ENDCONDITION%% devono essere inserite ognuna in un paragrafo a sè stante.';

?>

==> cms-db_v0.8.1.tar.gz: admin/locales/it/locale_variables.php <==
<?php
/*  cms-db  Copyright (C) 2007-2010 Jan Hoffmann
    For a full list of authors, see info.php
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

$locale['variables'] = array();

$locale['variables']['title'] = 'Variabili';
$locale['variables']['desc'] = 'Puoi utilizzare tutte le variabili all\'interno del <a href="%s">template</a>, le variabili, ad eccezione di PAGECONTENT, possono anche essere utilizzate nelle <a href="%s">pagine</a>. Non è permesso l\'inserimento di variabili all\'interno di commenti nel libro degli ospiti o negli articoli del blog.';

$locale['variables']['title_variables-menu'] = 'Menù';
$locale['variables']['title_variables-contentstructure'] = 'Contenuto e struttura';
$locale['variables']['title_variables-dynamic'] = 'Contenuto dinamico';
$locale['variables']['title_variables-blog'] = 'Blog';
$locale['variables']['title_variables-misc'] = 'Varie';

$locale['variables']['desc_p-allowed'] = 'può essere inserita in un paragrafo';
$locale['variables']['desc_p-alone'] = 'può essere inserita in un paragrafo, a condizione che il paragrafo non contenga altro.';
$locale['variables']['desc_p-disallowed'] = 'non può essere inserita in un paragrafo';
$locale['variables']['desc_p-needed'] = 'deve essere inserita in un paragrafo ed esserne l\'unico contenuto';

$locale['variables']['desc_topmenu'] = 'Genera un menù delle pagine primarie';
$locale['variables']['desc_completesubmenu'] = 'Genera un menù di tutte le pagine secondarie rispetto all\'attuale pagina primaria';
$locale['variables']['desc_foldingsubmenu'] = 'Genera un menù di tutte le pagine secondarie rispetto all\'attuale pagina primaria, relativo alla pagina secondaria attiva ';
$locale['variables']['desc_completemenu'] = 'Genera un menù completo del sito';
$locale['variables']['desc_foldingmenu'] = 'Genera un menù completo del sito, relativo alla pagina attiva';
$locale['variables']['desc_pagesearch'] = 'Genera un campo di ricerca';
$locale['variables']['desc_pagetitle'] = 'Nome della pagina corrente';
$locale['variables']['desc_fulltitle'] = 'Nome della pagina corrente e struttura della pagina';
$locale['variables']['desc_breadcrumbs'] = 'Come %%FULLTITLE%%, ma con link alle pagine';
$locale['variables']['desc_pagecontent'] = 'Contenuto della pagina corrente';
$locale['variables']['desc_lastedit'] = 'Data e orario dell\'ultima modifica alla pagina corrente';
$locale['variables']['desc_pagecount'] = 'Numero di visite alla pagina';
$locale['variables']['desc_counter'] = 'Numero di visitatori';
$locale['variables']['desc_sitemap'] = 'Genera una mappa del sito (se inserita in un paragrafo, questo verrà automaticamente rimosso)';
$locale['variables']['desc_mailform'] = 'Genera un modulo di contatto che manda un messaggio via email all\'indirizzo specificato in luogo di ADDRESS (se inserita in un paragrafo, questo verrà automaticamente rimosso)';
$locale['variables']['desc_guestbook'] = 'Libro degli ospiti, la codifica deve essere UTF-8 (se inserita in un paragrafo, questo verrà automaticamente rimosso)';
$locale['variables']['desc_blog'] = 'Blog, la codifica deve essere UTF-8 (se inserita in un paragrafo, questo verrà automaticamente rimosso)';
$locale['variables']['desc_latestblogarticles'] = 'Lista degli ultimi articoli del blog, PAGE è l\'URL relativo della pagina contenente il blog';
$locale['variables']['desc_tagcloud'] = 'Tag cloud (nuvola dei tag) del blog, PAGE è l\'URL relativo della pagina contenente il blog';
$locale['variables']['desc_completeblogfeed'] = 'Link al feed completo del blog, PAGE è l\'URL relativo della pagina contenente il blog';
$locale['variables']['desc_allblogfeeds'] = 'Lista di tutti i feed disponibili (per etichetta), , PAGE è l\'URL relativo della pagina contenente il blog (se inserita in un paragrafo, questo verrà automaticamente rimosso)';
$locale['variables']['desc_contextblogfeeds'] = 'Lista sensibile al contesto di tutti i feed disponibili (solo per il blog), , PAGE è l\'URL relativo della pagina contenente il blog (se inserita in un paragrafo, questo verrà automaticamente rimosso)';
$locale['variables']['desc_sectionlist'] = 'Lista dei link alle pagine figlie della pagina corrente (se inserita in un paragrafo, questo verrà automaticamente rimosso)';
$locale['variables']['desc_loginform'] = 'Modulo per il login (se inserita in un paragrafo, questo verrà automaticamente rimosso)';
$locale['variables']['desc_include'] = 'Mostra l\'include NAME (se inserita in un paragrafo, questo verrà automaticamente rimosso). Cosiddetti "late include" verranno sostituiti il più tardi possibile';
$locale['variables']['desc_redirect'] = 'Redirect all\'URL, i contenuti della pagina non veranno mostrati';
$locale['variables']['desc_forcelanguage'] = 'Imposta la lingua utilizzata per generare i contenuti al valore specificato con LANGCODE';
$locale['variables']['desc_urlsettings'] = 'Ritorna le impostazioni per l\'URL';
$locale['variables']['desc_completeurl'] = 'URL completo dellapagina corrente (compreso il dominio)';
$locale['variables']['desc_condition'] = 'Il contenuto inserito tra le due variabili sarà mostrato solo nel caso che il valore di COND sia "true", %%CONDITION-(COND)%% e %%ENDCONDITION%% devono essere inserite ognuna in un paragrafo a sè stante.';

?>
